from com.sg.u import utils as u
from com.sg.u.dbUtil import dbUtil as db
from com.sg.u.apiHttp import Http


class AutoParams:

    def __init__(self, dbBo, globalParam, resultInfo):
        self.__db_Bo = db(dbBo)
        self.__global_param = globalParam
        self.__result_info = resultInfo
        self.http = Http({})
        self.print_log = False
        self.write_log = False

    def querySql(self, sql):
        if sql is None or sql == '':
            self.setInfo(f"sql为空请检查!")
            return 0

        if self.__db_Bo.checkConnect():
            results = self.__db_Bo.query(sql)
            self.setInfo(f"查找到{len(results)}条数据sql:{sql}")
            return results
        else:
            self.setInfo("数据库未连接不执行sql请检查数据库配置:" + sql)
            return []

    def executeSql(self, sql):
        if sql is None or sql == '':
            self.setInfo(f"sql为空请检查!")
            return 0
        else:
            sql = sql.strip()
        if self.__db_Bo.checkConnect():
            des = '更新'
            if sql.lower().startswith("insert"):
                des = '新增'
            elif sql.lower().startswith("delete"):
                des = '删除'
            count = self.__db_Bo.exec(sql)
            if count is None:
                self.setError(f"未{des}任何数据请检查数据库链接sql:{sql}")
            else:
                self.setWarn(f"{des}{count}条数据sql:{sql}")
            return count
        else:
            self.setInfo("数据库未连接不执行sql请检查数据库配置:" + sql)
            return 0

    def getParam(self, key):
        try:
            return self.__global_param[key]
        except Exception as err:
            return None

    def putParam(self, key, value):
        self.__global_param[key] = value

    def setOut(self, s):
        self.__result_info["infos"].append("out:" + s)
        self.printLog("out:" + s)

    def setInfo(self, s):
        self.__result_info["infos"].append("info:" + s)
        self.printLog("info:" + s)

    def setWarn(self, s):
        self.__result_info["infos"].append("warn:" + s)
        self.printLog("warn:" + s)

    def setError(self, s):
        self.__result_info["errors"].append("error:" + s)
        self.__result_info["success"] = False
        self.__result_info["infos"].append("error:" + s)
        self.printLog("error:" + s)

    def printLog(self, s):
        if self.print_log:
            print(s)
        if self.write_log:
            u.writeLog(s)

    def openWriteLog(self, s):
        self.write_log = s

    def openPrintLog(self):
        self.print_log = True

    def getDbBo(self):
        return self.__db_Bo

    def getResultInfo(self):
        return self.__result_info

    def getGlobal(self):
        return self.__global_param

    def close(self):
        self.__db_Bo.close()

    def httpGet(self, url):
        if u.isEmpty(url):
            self.setWarn("url为空请检查")
            return {'code': 500, 'message': 'url为空请检查'}
        else:
            return self.http.get(url=url, log=self.print_log)

    def httpPost(self, url, json):
        if u.isEmpty(url):
            self.setWarn("url为空请检查")
            return {'code': 500, 'message': 'url为空请检查'}
        else:
            return self.http.post(url=url, json=json, log=self.print_log)

    def httpUpload(self, url, files, data):
        if u.isEmpty(url):
            self.setWarn("url为空请检查")
            return {'code': 500, 'message': 'url为空请检查'}
        else:
            return self.http.upload(url=url, files=files, data=data, log=self.print_log)

    def httpHeader(self, key, value):
        self.http.set_header(key=key, value=value)

    def httpGeHeader(self, key):
        if u.isEmpty(key):
            self.setWarn("key为空请检查")
            return ''
        else:
            return self.http.get_header(key)



import hashlib
import random
import json
from datetime import datetime, timedelta
import uuid
from dateutil.relativedelta import relativedelta
import os
import decimal

def randomxx(a, b):
    return random.uniform(a, b)


def writeText(path, dataList):
    file = open(path, "w")
    for s in dataList:
        file.write(s + '\n')
    file.close()


def writePfText(path, dataList):
    file = open(path, "w")
    for s in dataList:
        req = json.loads(s['req'])
        file.write(req[0] + '\n')
    file.close()


def writePfTextOne(path, text):
    file = open(path, "a")
    file.write(text + '\n')
    file.close()


def writeLog(text):
    print(text)
    # 1. 获取当前文件的绝对路径
    current_path = os.path.abspath(__file__)
    # 2. 获取当前文件所在的目录（项目根目录）
    project_root = os.path.dirname(current_path)
    # 3. 获取上一级目录
    parent_dir = os.path.dirname(project_root)
    # 4. 拼接 log 文件夹路径
    file_path = os.path.join(parent_dir, 'logs/python')
    # 5. 创建文件夹（如果不存在）
    os.makedirs(file_path, exist_ok=True)
    if os.path.exists(file_path):
        file = open(f"{file_path}/python-log{get_now_time('%Y%m%d')}.log", "a", encoding='utf-8')
        file.write(text + '\n')
        file.close()


def readText(path):
    data = []
    with open(path, 'r') as file:
        lines = file.readlines()
        for index, line in enumerate(lines):
            # print(line)
            if index != 0:
                data.append(line.replace('\n', ''))
    return data


def isEmpty(s):
    try:
        if s is None:
            return True
        elif not s:
            return True
        elif is_number(s):
            return False
        elif is_object(s):
            return len(s) == 0
        elif s.strip() == "":
            return True
        else:
            return False
    except:
        if len(s) == 0:
            return True
        else:
            return False


def isEmptyObject(s):
    if s is None:
        return True
    else:
        return False

def is_number(var):
    return type(var) in (int, float, complex) or type(var) is decimal.Decimal


def is_datetime(var):
    return type(var) is datetime


def is_str(var):
    return type(var) is str

def is_object(var):
    return type(var) in (list, dict, map, tuple)

def md5_hash(input_string):
    # 创建一个md5对象
    hash_object = hashlib.md5(input_string.encode())
    # 获取md5哈希的16进制字符串表示
    hex_dig = hash_object.hexdigest()
    return hex_dig


def get_now_time(format='%Y-%m-%d %H:%M:%S'):
    if format == '' or format == None:
        return datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    else:
        return datetime.now().strftime(format)


def bu_zero(s, num):
    return str(s).zfill(num)


def get_timestamp():
    return int(datetime.now().timestamp())


def get_time_by_day(format, day=0):
    if day == '' or day == None:
        day = 0
    # 当前日期
    current_date = datetime.now()
    # 计算前day天的日期
    five_days_ago = current_date + timedelta(days=day)
    if format == '' or format == None:
        return five_days_ago.strftime('%Y-%m-%d %H:%M:%S')
    else:
        return five_days_ago.strftime(format)

def get_time_by_month(format, month=0):
    if month == '' or month == None:
        month = 0
    # 当前日期
    current_date = datetime.now()
    # 计算前day天的日期
    five_days_ago = current_date + relativedelta(months=month)
    if format == '' or format == None:
        return five_days_ago.strftime('%Y-%m-%d %H:%M:%S')
    else:
        return five_days_ago.strftime(format)

def uuid4(replace=""):
    return str(uuid.uuid4()).replace("-", replace)



import requests
import json
import urllib3

class Http:
    def __init__(self, header):
        if (not header):
            self.__header = {}
        else:
            self.__header = header
        urllib3.disable_warnings()

    def get(self, url, log=False):
        if log:
            print('get请求:', url)
        res = requests.get(
            url=url,
            headers=self.__header,verify=False
        )
        if log:
            print(res.text)
        try:
            return json.loads(res.text)
        except Exception as e:
            return res.text


    def postForm(self, url, data,log=False):
        self.__header["Content-Type"] = "application/x-www-form-urlencoded"
        res = requests.post(url=url,
                            headers=self.__header,
                            data=data,verify=False)
        if log:
            print(res.text)
        try:
            return json.loads(res.text)
        except Exception as e:
            return res.text

    def post(self, url, jsons, log=False):
        if log:
            print('post请求:', url, jsons)
        self.__header["Content-Type"] = "application/json"
        res = requests.post(url=url,
                            headers=self.__header,
                            json=jsons,verify=False)
        if log:
            print(res.text)
        try:
            return json.loads(res.text)
        except Exception as e:
            return res.text

    def upload(self, url, files, data, log=False):
        if log:
            print('upload请求:', url, files)
        del self.__header["Content-Type"]
        res = requests.request("POST", url, headers=self.__header, data=data, files=files,verify=False)
        if log:
            print(res.text)
        try:
            return json.loads(res.text)
        except Exception as e:
            return res.text

    def set_headers(self, header):
        for key in header:
            self.__header[key] = header[key]

    def set_header(self, key , value):
        self.__header[key] = value

    def get_header(self, key ):
        try:
            return self.__header[key]
        except:
            return ''



from com.sg.u.autoParams import AutoParams


class Test:

    def changeRiskTool(self, request: AutoParams):
        print("xxxxxxxxxxxxxxxxxxxxxxxxxxxxx")
        request.setInfo("hahhahahahhahahahha")
        request.putParam("aaaa", "12345678")
        re = request.querySql("select * from otoc_store.t_sales_bind_store where store_no='SH202312111345434656'")
        request.putParam("query", re)


if __name__ == '__main__':
    sql='INSERT INTO otoc_store.t_sales_bin'
    des='新增' if sql.strip().lower().startswith("insert") else '更新'
    print(des)



import pymysql

from com.sg.u import utils as u


class dbUtil:
    def __init__(self, dbBo: dict):

        self.conn = None if dbBo is None or len(dbBo) == 0 else pymysql.connect(
            host=dbBo['url'].split('?')[0].split('//')[1].split(':')[0],  # 数据库地址
            user=dbBo['userName'],  # 数据库用户名
            password=dbBo['password'],  # 数据库密码
            port=int(dbBo['url'].split('?')[0].split('//')[1].split(':')[1]),
            # db='api_test',
            charset='utf8'
        )
        self.cur = None if self.conn is None else self.conn.cursor()

    #def __del__(self):  # 析构函数，实例删除时触发


    def query(self, sql):
        if self.cur is None:
            return []
        self.cur.execute(sql)
        column_names = [column[0] for column in self.cur.description]
        results = []
        rows = self.cur.fetchall()
        # 遍历每一行
        for row in rows:
            result = {}
            # 遍历每个字段的值
            i = 0
            for field_value in row:
                result[column_names[i]] = field_value
                i += 1
            results.append(result)
        return results

    def queryTableHeader(self, sql):
        self.cur.execute(sql)
        column_names = [column[0] for column in self.cur.description]

        # 打印字段信息
        print('字段信息：')
        for name in column_names:
            print(name)

    def exec(self, sql):
        if self.cur is None:
            return None
        try:
            self.cur.execute(sql)
            self.conn.commit()
            return self.cur.rowcount
        except Exception as e:
            self.conn.rollback()
            u.writeLog(str(e))
            return None

    def checkConnect(self):
        return False if self.conn is None else True

    def close(self):
        if self.cur is not None:
            self.cur.close()
        if self.conn is not None:
            self.conn.close()

if __name__ == '__main__':
    # 创建连接
    url="jdbc:mysql://gz-cdb-3h872lmp.sql.tencentcdb.com:63975?useUnicode=true&characterEncoding=UTF-8&serverTimezone" \
        "=Asia/Shanghai&nullCatalogMeansCurrent=true".split("?")[0].split("//")[1].split(":")
    dbBo = {"domain": url[0],"port":url[1],"user":"otoctest","password":"cYgnuNEeM3"}
    print(dbBo)
    db = dbUtil(dbBo)
    # print(db.queryTableHeader("select * from otoc_store.t_sales_bind_store where store_no='SH202312111345434656'"))
    print(db.query("select * from otoc_store.t_sales_bind_store where store_no='SH202312111345434656'"))
